package App::perldolicious;

our $VERSION = '0.007';
$VERSION = eval $VERSION;

1;

=pod

=head1 NAME

App::perldolicious - Mojolicious::Lite webapp that lets you search (with regexp) and display CPAN modules documentation

=head1 VERSION

Version 0.007.

=head1 DESCRIPTION

See the documentation of B<perldolicious(1)>.

=head1 AUTHOR

Ahmad Syaltut <Isyaltut@gmail.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Ahmad Syaltut.

This is free software; you can redistribute it and/or modify it under the same
terms as the Perl 5 programming language system itself.
